//+------------------------------------------------------------------+
//|                                         Range_Breakout_Alert.mq4 |
//|                                                         Zen_Leow |
//|                                             Modified by Mikhail  |
//|                                      http://www.landofcash.net   |
//+------------------------------------------------------------------+
#property copyright "Zen_Leow"
#property link      ""

#property indicator_chart_window

extern int LengthOfRangeBox = 12;
extern int MinimumPipRange = 25;
extern int MaximumPipRange = 1000;
extern color RangeBoxColor = Blue;
extern color DynamicFiboColor = Maroon;
extern bool EnableAlert=true;
extern bool SendEmail=true;

int PipFactor = 1;
double HighestHighInBox, LowestLowInBox;
datetime LastUpAlertTime = 0;
datetime LastDownAlertTime = 0;
string TimeFrame_Str = "";
bool RangeValid = false;
int PipRange = 0;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   TimeFrame_Str = "";
   int TimeFrame = Period();
   if (TimeFrame == 0)
   {
      TimeFrame_Str = "("+Period()+")";
      TimeFrame = Period();
   }
   if (TimeFrame == PERIOD_M1)
   {
      TimeFrame_Str = "(M1)";
   }
   if (TimeFrame == PERIOD_M5)
   {
      TimeFrame_Str = "(M5)";
   }
   if (TimeFrame == PERIOD_M15)
   {
      TimeFrame_Str = "(M15)";
   }
   if (TimeFrame == PERIOD_M30)
   {
      TimeFrame_Str = "(M30)";
   }
   if (TimeFrame == PERIOD_H1)
   {
      TimeFrame_Str = "(H1)";
   }
   if (TimeFrame == PERIOD_H4)
   {
      TimeFrame_Str = "(H4)";
   }
   if (TimeFrame == PERIOD_D1)
   {
      TimeFrame_Str = "(D1)";
   }
   if (TimeFrame == PERIOD_W1)
   {
      TimeFrame_Str = "(W1)";
   }
   if (TimeFrame == PERIOD_MN1)
   {
      TimeFrame_Str = "(MN1)";
   }
   // Cater for fractional pips
   if (Digits == 3 || Digits == 5)
   {
      PipFactor = 10;
   }
   ObjectDelete("RangeBox");
   ObjectDelete("DynamicFibo");
   LastUpAlertTime = 0;
   LastDownAlertTime = 0;
   RangeValid = false;
   int PipRange = 0;
//----
   return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
//----
   ObjectDelete("RangeBox");
   ObjectDelete("DynamicFibo");
   LastUpAlertTime = 0;
   LastDownAlertTime = 0;
//----
   return(0);
}

void Draw_RangeBox_And_Fibo()
{
   RangeValid = false;
   int HighestIndex = iHighest(NULL,0,MODE_HIGH,LengthOfRangeBox,1);
   HighestHighInBox = High[HighestIndex];
   int LowestIndex = iLowest(NULL,0,MODE_LOW,LengthOfRangeBox,1);
   LowestLowInBox = Low[LowestIndex];
   PipRange = (HighestHighInBox - LowestLowInBox) / (Point * PipFactor);
   if (PipRange >= MinimumPipRange && PipRange <= MaximumPipRange)
   {
      RangeValid = true;
   }
   if (RangeValid)
   {
      if (ObjectFind("RangeBox") == -1)
      {
         ObjectCreate("RangeBox", OBJ_RECTANGLE, 0, Time[LengthOfRangeBox], HighestHighInBox, Time[1], LowestLowInBox);
      }
      ObjectSet("RangeBox", OBJPROP_TIME1, Time[LengthOfRangeBox]);
      ObjectSet("RangeBox", OBJPROP_PRICE1, HighestHighInBox);
      ObjectSet("RangeBox", OBJPROP_TIME2, Time[1]);
      ObjectSet("RangeBox", OBJPROP_PRICE2, LowestLowInBox);
      ObjectSet("RangeBox", OBJPROP_COLOR, RangeBoxColor);
   
      if (ObjectFind("DynamicFibo") == -1)
      {
         ObjectCreate("DynamicFibo", OBJ_FIBO, 0, Time[HighestIndex], HighestHighInBox, Time[LowestIndex], LowestLowInBox);
      }
      ObjectSet("DynamicFibo", OBJPROP_TIME1, Time[HighestIndex]);
      ObjectSet("DynamicFibo", OBJPROP_PRICE1, HighestHighInBox);
      ObjectSet("DynamicFibo", OBJPROP_TIME2, Time[LowestIndex]);
      ObjectSet("DynamicFibo", OBJPROP_PRICE2, LowestLowInBox);
      ObjectSet("DynamicFibo", OBJPROP_COLOR, DynamicFiboColor);
   }
   else
   {
      if (ObjectFind("RangeBox") != -1)
      {
         ObjectDelete("RangeBox");
      }
      if (ObjectFind("DynamicFibo") != -1)
      {
         ObjectDelete("DynamicFibo");
      }
      
   }
}

void TrackAlert()
{
   if (High[0] > HighestHighInBox && LastUpAlertTime != Time[0] && RangeValid)
   {
      if(EnableAlert){
         Alert(Symbol()+" Upward Breakout of "+LengthOfRangeBox+" bar range on "+TimeFrame_Str+" "+TimeToStr(TimeCurrent(),TIME_SECONDS));
      }
      if(SendEmail){
         SendMail ("UPWARD Breakout on "+Symbol(), Symbol()+" Upward Breakout of "+LengthOfRangeBox+" bar range on "+TimeFrame_Str+" "+TimeToStr(TimeCurrent(),TIME_SECONDS));
      }
      LastUpAlertTime = Time[0];
   }
   if (Low[0] < LowestLowInBox && LastDownAlertTime != Time[0] && RangeValid)
   {
      if(EnableAlert){
         Alert(Symbol()+" Downward Breakout of "+LengthOfRangeBox+" bar range on "+TimeFrame_Str+" "+TimeToStr(TimeCurrent(),TIME_SECONDS));
      }
      if(SendEmail){
         SendMail ("DOWNWARD Breakout on "+Symbol(), Symbol()+" Downward Breakout of "+LengthOfRangeBox+" bar range on "+TimeFrame_Str+" "+TimeToStr(TimeCurrent(),TIME_SECONDS));
      }
      LastDownAlertTime = Time[0];
   }
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
//----
   Draw_RangeBox_And_Fibo();
   TrackAlert();
   if (RangeValid)
   {
      Comment("Range is within boundaries. Range Box and Fibo Drawn");
   }
   else
   {
      Comment("Range is outside of boundaries. Nothing Drawn");
   }
//----
   return(0);
}
//+------------------------------------------------------------------+